@@ -1,3 +1,4 @@
+import logging
 import platform
 import threading
 import time
@@ -5,11 +6,13 @@ import traceback
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 from ._debug import info as debug_info  # noqa: F401
-from ._debug import log
 from ._version import __author__, __version__  # noqa: F401
 from .helpers import MONITOR_MANUFACTURER_CODES  # noqa: F401
 from .helpers import ScreenBrightnessError, logarithmic_range
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
 
 def get_brightness(
     display: Optional[Union[int, str]] = None,
@@ -189,7 +192,7 @@ def fade_brightness(
         if start > finish:
             increment = -increment
 
-        log.debug(
+        logger.debug(
             f'fade display {monitor.index} of {monitor.method}'
             f' {start}->{finish}:{increment}:logarithmic={logarithmic}'
         )
@@ -244,7 +247,7 @@ def fade_brightness(
             t1.start()
             threads.append(t1)
         except Exception as e:
-            log.debug(f'exception when preparing to fade monitor {i} - {type(e).__name__}: {e}')
+            logger.error(f'exception when preparing to fade monitor {i} - {type(e).__name__}: {e}')
             pass
 
     if not blocking:
@@ -418,6 +421,8 @@ class Monitor():
         self.edid: str = info.pop('edid')
         '''a unique string returned by the monitor that contains its DDC capabilities, serial and name'''
 
+        self._logger = logger.getChild(self.__class__.__name__).getChild(str(self.get_identifier()[1])[:20])
+
         # this assigns any extra info that is returned to this class
         # eg: the 'interface' key in XRandr monitors on Linux
         for key, value in info.items():
@@ -582,8 +587,11 @@ class Monitor():
             info = primary.get_info()
             ```
         '''
+        def vars_self():
+            return {k: v for k, v in vars(self).items() if not k.startswith('_')}
+
         if not refresh:
-            return vars(self)
+            return vars_self()
 
         identifier = self.get_identifier()
 
@@ -594,7 +602,7 @@ class Monitor():
                 if value is not None:
                     setattr(self, key, value)
 
-        return vars(self)
+        return vars_self()
 
     def is_active(self) -> bool:
         '''
@@ -616,7 +624,7 @@ class Monitor():
             self.get_brightness()
             return True
         except Exception as e:
-            log.debug(
+            self._logger.error(
                 f'Monitor.is_active: {self.get_identifier()} failed get_brightness call'
                 f' - {type(e).__name__}: {e}'
             )
@@ -734,8 +742,7 @@ def __brightness(
     verbose_error=False, **kwargs
 ):
     '''Internal function used to get/set brightness'''
-
-    log.debug(f"brightness {meta_method} request display {display} with method {method}")
+    logger.debug(f"brightness {meta_method} request display {display} with method {method}")
 
     def format_exc(name, e):
         errors.append((
@@ -802,4 +809,4 @@ elif platform.system() == 'Linux':
     from . import linux
     _OS_MODULE = linux
 else:
-    log.warning(f'package imported on unsupported platform ({platform.system()})')
+    logger.warning(f'package imported on unsupported platform ({platform.system()})')
